==> libreoffice-l10n_4.2.7.orig-src.tar.xz: libwpd-0.9.9/src/lib/WP1UnsupportedFixedLengthGroup.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libwpd
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
 * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
 * Copyright (c) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP1UNSUPPORTEDFIXEDLENGTHGROUP_H
#define WP1UNSUPPORTEDFIXEDLENGTHGROUP_H

#include "WP1FixedLengthGroup.h"

// a pedantic and irritating class that we should only need until we completely cover wordperfect's
// set of variable length groups (there are a finite number)

class WP1UnsupportedFixedLengthGroup : public WP1FixedLengthGroup
{
public:
	WP1UnsupportedFixedLengthGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t group);

	void _readContents(WPXInputStream *input, WPXEncryption *encryption);
	void parse(WP1Listener * /* listener */) {}
};

#endif /* WP1UNSUPPORTEDFIXEDLENGTHGROUP_H */
/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */

==> libreoffice-l10n_4.4.3~rc2.orig-src.tar.xz: libwpd-0.10.0/src/lib/WP1UnsupportedFixedLengthGroup.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libwpd
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
 * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
 * Copyright (c) 2006 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP1UNSUPPORTEDFIXEDLENGTHGROUP_H
#define WP1UNSUPPORTEDFIXEDLENGTHGROUP_H

#include "WP1FixedLengthGroup.h"

// a pedantic and irritating class that we should only need until we completely cover wordperfect's
// set of variable length groups (there are a finite number)

class WP1UnsupportedFixedLengthGroup : public WP1FixedLengthGroup
{
public:
	WP1UnsupportedFixedLengthGroup(librevenge::RVNGInputStream *input, WPXEncryption *encryption, unsigned char group);

	void _readContents(librevenge::RVNGInputStream *input, WPXEncryption *encryption);
	void parse(WP1Listener * /* listener */) {}
};

#endif /* WP1UNSUPPORTEDFIXEDLENGTHGROUP_H */
/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
